@@ -5,7 +5,7 @@ use warnings;
 
 # ABSTRACT: Standard filesystem driver for Rapi::Fs
 
-use feature 'switch';
+use experimental 'switch';
 
 use Moo;
 with 'Rapi::Fs::Role::Driver';
@@ -271,7 +271,7 @@ sub node_get_code_language {
   my $ext = $Node->file_ext or return undef;
 
   for($ext) {
-    no warnings 'experimental';
+    no if try{warnings::enabled('experimental')}, warnings => 'experimental';
 
     when([qw/pl pm pod t psgi/])   { return 'perl' }
     when([qw/css/])           { return 'css' }
